@@ -2,10 +2,4 @@
 def simplechat_dictionary_run(input_charecter_dictionary, input_dictionary_dictionary):
     while True:
         input_question_dictionary = input(input_charecter_dictionary)
-        print(input_dictionary_dictionary[input_question_dictionary])
-
-test = {
-    "Hello":"Hi"
-}
-
-simplechat_dictionary_run(">", test)
\ No newline at end of file
+        print(input_dictionary_dictionary[input_question_dictionary])
\ No newline at end of file
